NewSave class

Inheritance

Constructors

NewSave()

Properties

coverImage String?
A cover image for the save (base64). Android only.
getter/setter pairinherited
description String?
An optional short description of the save. Android only.
getter/setter pairinherited
deviceName String
The device that saved the game.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
modificationDate int
The saved game's modification date (in milliseconds). When the saved game is first created, this will be the creation date.
getter/setter pairinherited
name String
The saved game's name.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timePlayed Duration?
Time played in the save. Android only.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited