PlayerData class

Constructors

PlayerData({required String? playerID, required String displayName, String? iconImage, String? teamPlayerID, bool? isUnderage, bool? isMultiplayerGamingRestricted, bool? isPersonalizedCommunicationRestricted})
const
PlayerData.fromJson(Map<String, dynamic> json)
factory

Properties

displayName String
final
hashCode int
The hash code for this object.
no setterinherited
iconImage String?
final
isMultiplayerGamingRestricted bool?
Only available from GameCenter.
final
isPersonalizedCommunicationRestricted bool?
Only available from GameCenter.
final
isUnderage bool?
Only available from GameCenter.
final
playerID String?
Value can be null on Android due to privacy settings or in the case of a GameCenter configuration issue, as GameCenter will provide a temporary ID which will not persist between game sessions.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
teamPlayerID String?
Only available from GameCenter. May be null if there is GameCenter configuration issue, as GameCenter will provide a temporary ID which will not persist between game sessions.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited