playerID property

String? playerID
final

Value can be null on Android due to privacy settings or in the case of a GameCenter configuration issue, as GameCenter will provide a temporary ID which will not persist between game sessions.

Implementation

final String? playerID;