SavedGame class

Implementers

Constructors

SavedGame(String name, int modificationDate, String deviceName, {String? description, Duration? timePlayed, String? coverImage})
SavedGame.fromJson(Map json)
factory

Properties

coverImage String?
A cover image for the save (base64). Android only.
getter/setter pair
description String?
An optional short description of the save. Android only.
getter/setter pair
deviceName String
The device that saved the game.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
modificationDate int
The saved game's modification date (in milliseconds). When the saved game is first created, this will be the creation date.
getter/setter pair
name String
The saved game's name.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timePlayed Duration?
Time played in the save. Android only.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited